package football

import (
	"git.lehouerou.net/laurent/sorare/graphql"
)

type Football struct {
	c *graphql.Client

	AllCards           *graphql.PaginatedQuery[Card, CardsParams]
	Card               *graphql.Query[Card, graphql.SlugParams]
	CardByAssetId      *graphql.Query[Card, graphql.AssetIdParams]
	CardByBlockchainId *graphql.Query[Card, graphql.BlockchainIdParams]
	Cards              *graphql.Query[[]Card, CardsParams]
	Club               *graphql.Query[Club, graphql.SlugParams]
	Clubs              *graphql.Query[[]Club, graphql.SlugsParams]
	ClubsReady         *graphql.Query[[]Club, graphql.EmptyParams]
	Competition        *graphql.Query[Competition, graphql.SlugParams]
	Game               *graphql.Query[GameWithFormation, graphql.IdParams]
	GamesFormation     *GamesFormationQuery
	GamesScores        *GamesScoresQuery
	MyLiveGames        *graphql.Query[[]Game, graphql.EmptyParams]
	NationalTeam       *graphql.Query[NationalTeam, graphql.SlugParams]
	NationalTeams      *graphql.Query[[]NationalTeam, graphql.SlugsParams]
	Player             *graphql.Query[Player, graphql.SlugParams]
	Players            *graphql.Query[[]Player, graphql.SlugsParams]
	Season             *graphql.Query[Season, SeasonParams]

	So5 *So5
}

func NewFootball(c *graphql.Client) *Football {
	return &Football{
		c: c,

		AllCards: graphql.NewPaginatedQuery[Card, CardsParams](
			c,
			"allCards",
			[]string{"football"},
		),
		Card: graphql.NewQuery[Card, graphql.SlugParams](
			c,
			"card",
			[]string{"football"},
		),
		CardByAssetId: graphql.NewQuery[Card, graphql.AssetIdParams](
			c,
			"cardByAssetId",
			[]string{"football"},
		),
		CardByBlockchainId: graphql.NewQuery[Card, graphql.BlockchainIdParams](
			c,
			"cardByBlockchainId",
			[]string{"football"},
		),
		Cards: graphql.NewQuery[[]Card, CardsParams](c, "cards", []string{"football"}),
		Club: graphql.NewQuery[Club, graphql.SlugParams](
			c,
			"club",
			[]string{"football"},
		),
		Clubs: graphql.NewQuery[[]Club, graphql.SlugsParams](
			c,
			"clubs",
			[]string{"football"},
		),
		ClubsReady: graphql.NewQuery[[]Club, graphql.EmptyParams](
			c,
			"clubsReady",
			[]string{"football"},
		),
		Competition: graphql.NewQuery[Competition, graphql.SlugParams](
			c,
			"competition",
			[]string{"football"},
		),
		Game: graphql.NewQuery[GameWithFormation, graphql.IdParams](
			c,
			"game",
			[]string{"football"},
		),
		GamesFormation: NewGamesFormationQuery(
			c,
		),
		GamesScores: NewGamesScoresQuery(
			c,
		),
		MyLiveGames: graphql.NewQuery[[]Game, graphql.EmptyParams](
			c,
			"myLiveGames",
			[]string{"football"},
		),
		NationalTeam: graphql.NewQuery[NationalTeam, graphql.SlugParams](
			c,
			"nationalTeam",
			[]string{"football"},
		),
		NationalTeams: graphql.NewQuery[[]NationalTeam, graphql.SlugsParams](
			c,
			"nationalTeams",
			[]string{"football"},
		),
		Player: graphql.NewQuery[Player, graphql.SlugParams](
			c,
			"player",
			[]string{"football"},
		),
		Players: graphql.NewQuery[[]Player, graphql.SlugsParams](
			c,
			"players",
			[]string{"football"},
		),
		Season: graphql.NewQuery[Season, SeasonParams](
			c,
			"season",
			[]string{"football"},
		),

		So5: NewSo5(c),
	}
}
